@@ -119,13 +119,7 @@ def get_nodes_controller_reserved_names():
     return _NODES_CONTROLLER_RESERVED_WORDS
 
 
-def hide_fields_in_newer_versions(obj):
-    """This method hides fields that were added in newer API versions.
-
-    Certain node fields were introduced at certain API versions.
-    These fields are only made available when the request's API version
-    matches or exceeds the versions when these fields were introduced.
-    """
+def _hide_fields_in_newer_versions_part_one(obj):
     if pecan.request.version.minor < versions.MINOR_3_DRIVER_INTERNAL_INFO:
         obj.driver_internal_info = wsme.Unset
 
@@ -150,6 +144,11 @@ def hide_fields_in_newer_versions(obj):
     if pecan.request.version.minor < versions.MINOR_42_FAULT:
         obj.fault = wsme.Unset
 
+    if pecan.request.version.minor < versions.MINOR_44_NODE_DEPLOY_STEP:
+        obj.deploy_step = wsme.Unset
+
+
+def _hide_fields_in_newer_versions_part_two(obj):
     if not api_utils.allow_resource_class():
         obj.resource_class = wsme.Unset
 
@@ -169,6 +168,22 @@ def hide_fields_in_newer_versions(obj):
     if not api_utils.allow_bios_interface():
         obj.bios_interface = wsme.Unset
 
+    if not api_utils.allow_conductor_group():
+        obj.conductor_group = wsme.Unset
+
+
+def hide_fields_in_newer_versions(obj):
+    """This method hides fields that were added in newer API versions.
+
+    Certain node fields were introduced at certain API versions.
+    These fields are only made available when the request's API version
+    matches or exceeds the versions when these fields were introduced.
+
+    This is broken into two methods for cyclomatic complexity's sake.
+    """
+    _hide_fields_in_newer_versions_part_one(obj)
+    _hide_fields_in_newer_versions_part_two(obj)
+
 
 def update_state_in_older_versions(obj):
     """Change provision state names for API backwards compatibility.
@@ -990,6 +1005,9 @@ class Node(base.APIBase):
     clean_step = wsme.wsattr({wtypes.text: types.jsontype}, readonly=True)
     """The current clean step"""
 
+    deploy_step = wsme.wsattr({wtypes.text: types.jsontype}, readonly=True)
+    """The current deploy step"""
+
     raid_config = wsme.wsattr({wtypes.text: types.jsontype}, readonly=True)
     """Represents the current RAID configuration of the node """
 
@@ -1068,6 +1086,9 @@ class Node(base.APIBase):
     bios_interface = wsme.wsattr(wtypes.text)
     """The bios interface to be used for this node"""
 
+    conductor_group = wsme.wsattr(wtypes.text)
+    """The conductor group to manage this node"""
+
     # NOTE(deva): "conductor_affinity" shouldn't be presented on the
     #             API because it's an internal value. Don't add it here.
 
@@ -1084,6 +1105,11 @@ class Node(base.APIBase):
                 # TODO(jroll) is there a less hacky way to do this?
                 if k == 'traits' and kwargs.get('traits') is not None:
                     value = [t['trait'] for t in kwargs['traits']['objects']]
+                # NOTE(jroll) this is special-cased to "" and not Unset,
+                # because it is used in hash ring calculations
+                elif k == 'conductor_group' and (k not in kwargs or
+                                                 kwargs[k] is wtypes.Unset):
+                    value = ''
                 else:
                     value = kwargs.get(k, wtypes.Unset)
                 setattr(self, k, value)
@@ -1215,7 +1241,7 @@ class Node(base.APIBase):
                      provision_updated_at=time, instance_info={},
                      maintenance=False, maintenance_reason=None, fault=None,
                      inspection_finished_at=None, inspection_started_at=time,
-                     console_enabled=False, clean_step={},
+                     console_enabled=False, clean_step={}, deploy_step={},
                      raid_config=None, target_raid_config=None,
                      network_interface='flat', resource_class='baremetal-gold',
                      boot_interface=None, console_interface=None,
@@ -1223,7 +1249,7 @@ class Node(base.APIBase):
                      management_interface=None, power_interface=None,
                      raid_interface=None, vendor_interface=None,
                      storage_interface=None, traits=[], rescue_interface=None,
-                     bios_interface=None)
+                     bios_interface=None, conductor_group="")
         # NOTE(matty_dubs): The chassis_uuid getter() is based on the
         # _chassis_uuid variable:
         sample._chassis_uuid = 'edcad704-b2da-41d5-96d9-afd580ecfa12'
@@ -1247,6 +1273,7 @@ class NodePatchType(types.JsonPatchType):
                            '/provision_updated_at', '/maintenance_reason',
                            '/driver_internal_info', '/inspection_finished_at',
                            '/inspection_started_at', '/clean_step',
+                           '/deploy_step',
                            '/raid_config', '/target_raid_config',
                            '/fault']
 
@@ -1484,7 +1511,8 @@ class NodesController(rest.RestController):
 
     invalid_sort_key_list = ['properties', 'driver_info', 'extra',
                              'instance_info', 'driver_internal_info',
-                             'clean_step', 'raid_config', 'target_raid_config',
+                             'clean_step', 'deploy_step',
+                             'raid_config', 'target_raid_config',
                              'traits']
 
     _subcontroller_map = {
@@ -1524,7 +1552,8 @@ class NodesController(rest.RestController):
                               maintenance, provision_state, marker, limit,
                               sort_key, sort_dir, driver=None,
                               resource_class=None, resource_url=None,
-                              fields=None, fault=None, detail=None):
+                              fields=None, fault=None, conductor_group=None,
+                              detail=None):
         if self.from_chassis and not chassis_uuid:
             raise exception.MissingParameterValue(
                 _("Chassis id not specified."))
@@ -1572,6 +1601,8 @@ class NodesController(rest.RestController):
                 filters['resource_class'] = resource_class
             if fault is not None:
                 filters['fault'] = fault
+            if conductor_group is not None:
+                filters['conductor_group'] = conductor_group
 
             nodes = objects.Node.list(pecan.request.context, limit, marker_obj,
                                       sort_key=sort_key, sort_dir=sort_dir,
@@ -1679,11 +1710,12 @@ class NodesController(rest.RestController):
     @expose.expose(NodeCollection, types.uuid, types.uuid, types.boolean,
                    types.boolean, wtypes.text, types.uuid, int, wtypes.text,
                    wtypes.text, wtypes.text, types.listtype, wtypes.text,
-                   wtypes.text, types.boolean)
+                   wtypes.text, wtypes.text, types.boolean)
     def get_all(self, chassis_uuid=None, instance_uuid=None, associated=None,
                 maintenance=None, provision_state=None, marker=None,
                 limit=None, sort_key='id', sort_dir='asc', driver=None,
-                fields=None, resource_class=None, fault=None, detail=None):
+                fields=None, resource_class=None, fault=None,
+                conductor_group=None, detail=None):
         """Retrieve a list of nodes.
 
         :param chassis_uuid: Optional UUID of a chassis, to get only nodes for
@@ -1709,6 +1741,8 @@ class NodesController(rest.RestController):
                        driver.
         :param resource_class: Optional string value to get only nodes with
                                that resource_class.
+        :param conductor_group: Optional string value to get only nodes with
+                                that conductor_group.
         :param fields: Optional, a list with a specified set of fields
                        of the resource to be returned.
         :param fault: Optional string value to get only nodes with that fault.
@@ -1723,6 +1757,7 @@ class NodesController(rest.RestController):
         api_utils.check_allow_specify_driver(driver)
         api_utils.check_allow_specify_resource_class(resource_class)
         api_utils.check_allow_filter_by_fault(fault)
+        api_utils.check_allow_filter_by_conductor_group(conductor_group)
 
         fields = api_utils.get_request_return_fields(fields, detail,
                                                      _DEFAULT_RETURN_FIELDS)
@@ -1734,16 +1769,18 @@ class NodesController(rest.RestController):
                                           driver=driver,
                                           resource_class=resource_class,
                                           fields=fields, fault=fault,
+                                          conductor_group=conductor_group,
                                           detail=detail)
 
     @METRICS.timer('NodesController.detail')
     @expose.expose(NodeCollection, types.uuid, types.uuid, types.boolean,
                    types.boolean, wtypes.text, types.uuid, int, wtypes.text,
-                   wtypes.text, wtypes.text, wtypes.text, wtypes.text)
+                   wtypes.text, wtypes.text, wtypes.text, wtypes.text,
+                   wtypes.text)
     def detail(self, chassis_uuid=None, instance_uuid=None, associated=None,
                maintenance=None, provision_state=None, marker=None,
                limit=None, sort_key='id', sort_dir='asc', driver=None,
-               resource_class=None, fault=None):
+               resource_class=None, fault=None, conductor_group=None):
         """Retrieve a list of nodes with detail.
 
         :param chassis_uuid: Optional UUID of a chassis, to get only nodes for
@@ -1770,6 +1807,8 @@ class NodesController(rest.RestController):
         :param resource_class: Optional string value to get only nodes with
                                that resource_class.
         :param fault: Optional string value to get only nodes with that fault.
+        :param conductor_group: Optional string value to get only nodes with
+                                that conductor_group.
         """
         cdict = pecan.request.context.to_policy_values()
         policy.authorize('baremetal:node:get', cdict, cdict)
@@ -1778,6 +1817,7 @@ class NodesController(rest.RestController):
         api_utils.check_allow_specify_driver(driver)
         api_utils.check_allow_specify_resource_class(resource_class)
         api_utils.check_allow_filter_by_fault(fault)
+        api_utils.check_allow_filter_by_conductor_group(conductor_group)
         api_utils.check_allowed_fields([sort_key])
         # /detail should only work against collections
         parent = pecan.request.path.split('/')[:-1][-1]
@@ -1792,7 +1832,8 @@ class NodesController(rest.RestController):
                                           driver=driver,
                                           resource_class=resource_class,
                                           resource_url=resource_url,
-                                          fault=fault)
+                                          fault=fault,
+                                          conductor_group=conductor_group)
 
     @METRICS.timer('NodesController.validate')
     @expose.expose(wtypes.text, types.uuid_or_name, types.uuid)
@@ -1887,6 +1928,12 @@ class NodesController(rest.RestController):
                 and node.rescue_interface is not wtypes.Unset):
             raise exception.NotAcceptable()
 
+        # NOTE(jroll) this is special-cased to "" and not Unset,
+        # because it is used in hash ring calculations
+        if (not api_utils.allow_conductor_group()
+                and node.conductor_group != ""):
+            raise exception.NotAcceptable()
+
         # NOTE(deva): get_topic_for checks if node.driver is in the hash ring
         #             and raises NoValidHost if it is not.
         #             We need to ensure that node has a UUID before it can
@@ -1926,7 +1973,7 @@ class NodesController(rest.RestController):
         return api_node
 
     # NOTE (yolanda): isolate validation to avoid patch too complex pep error
-    def _validate_patch(self, patch):
+    def _validate_patch(self, patch, reset_interfaces):
         if self.from_chassis:
             raise exception.OperationNotPermitted()
 
@@ -1961,20 +2008,37 @@ class NodesController(rest.RestController):
         if b_interface and not api_utils.allow_bios_interface():
             raise exception.NotAcceptable()
 
+        driver = api_utils.get_patch_values(patch, '/driver')
+        if reset_interfaces and not driver:
+            msg = _("The reset_interfaces parameter can only be used when "
+                    "changing the node's driver.")
+            raise exception.Invalid(msg)
+
+        conductor_group = api_utils.get_patch_values(patch, '/conductor_group')
+        if conductor_group and not api_utils.allow_conductor_group():
+            raise exception.NotAcceptable()
+
     @METRICS.timer('NodesController.patch')
-    @wsme.validate(types.uuid, [NodePatchType])
-    @expose.expose(Node, types.uuid_or_name, body=[NodePatchType])
-    def patch(self, node_ident, patch):
+    @wsme.validate(types.uuid, types.boolean, [NodePatchType])
+    @expose.expose(Node, types.uuid_or_name, types.boolean,
+                   body=[NodePatchType])
+    def patch(self, node_ident, reset_interfaces=None, patch=None):
         """Update an existing node.
 
         :param node_ident: UUID or logical name of a node.
+        :param reset_interfaces: whether to reset hardware interfaces to their
+            defaults. Only valid when updating the driver field.
         :param patch: a json PATCH document to apply to this node.
         """
         context = pecan.request.context
         cdict = context.to_policy_values()
         policy.authorize('baremetal:node:update', cdict, cdict)
 
-        self._validate_patch(patch)
+        if (reset_interfaces is not None and not
+                api_utils.allow_reset_interfaces()):
+            raise exception.NotAcceptable()
+
+        self._validate_patch(patch, reset_interfaces)
 
         rpc_node = api_utils.get_rpc_node_with_suffix(node_ident)
 
@@ -2035,7 +2099,8 @@ class NodesController(rest.RestController):
         with notify.handle_error_notification(context, rpc_node, 'update',
                                               chassis_uuid=node.chassis_uuid):
             new_node = pecan.request.rpcapi.update_node(context,
-                                                        rpc_node, topic)
+                                                        rpc_node, topic,
+                                                        reset_interfaces)
 
         api_node = Node.convert_with_links(new_node)
         notify.emit_end_notification(context, new_node, 'update',
