@@ -149,8 +149,7 @@ def require_exclusive_lock(f):
     return wrapper
 
 
-def acquire(context, node_id, shared=False, purpose='unspecified action',
-            **kwargs):
+def acquire(context, node_id, shared=False, purpose='unspecified action'):
     """Shortcut for acquiring a lock on a Node.
 
     :param context: Request context.
@@ -163,8 +162,7 @@ def acquire(context, node_id, shared=False, purpose='unspecified action',
     """
     # NOTE(lintan): This is a workaround to set the context of periodic tasks.
     context.ensure_thread_contain_context()
-    return TaskManager(context, node_id, shared=shared, purpose=purpose,
-                       **kwargs)
+    return TaskManager(context, node_id, shared=shared, purpose=purpose)
 
 
 class TaskManager(object):
@@ -176,8 +174,7 @@ class TaskManager(object):
     """
 
     def __init__(self, context, node_id, shared=False,
-                 purpose='unspecified action',
-                 load_driver=True):
+                 purpose='unspecified action'):
         """Create a new TaskManager.
 
         Acquire a lock on a node. The lock can be either shared or
@@ -190,9 +187,6 @@ class TaskManager(object):
         :param shared: Boolean indicating whether to take a shared or exclusive
                        lock. Default: False.
         :param purpose: human-readable purpose to put to debug logs.
-        :param load_driver: whether to load the ``driver`` object. Set this to
-                            False if loading the driver is undesired or
-                            impossible.
         :raises: DriverNotFound
         :raises: InterfaceNotFoundInEntrypoint
         :raises: NodeNotFound
@@ -237,10 +231,7 @@ class TaskManager(object):
                 context, self.node.id)
             self.volume_targets = objects.VolumeTarget.list_by_node_id(
                 context, self.node.id)
-            if load_driver:
-                self.driver = driver_factory.build_driver_for_task(self)
-            else:
-                self.driver = None
+            self.driver = driver_factory.build_driver_for_task(self)
 
         except Exception:
             with excutils.save_and_reraise_exception():
@@ -435,8 +426,8 @@ class TaskManager(object):
 
         :param event: the name of the event to process
         :param callback: optional callback to invoke upon event transition
-        :param call_args: optional \*args to pass to the callback method
-        :param call_kwargs: optional \**kwargs to pass to the callback method
+        :param call_args: optional args to pass to the callback method
+        :param call_kwargs: optional kwargs to pass to the callback method
         :param err_handler: optional error handler to invoke if the
                 callback fails, eg. because there are no workers available
                 (err_handler should accept arguments node, prev_prov_state, and
