@@ -30,7 +30,6 @@ import six
 
 from ironic.common import exception
 from ironic.common.glance_service import service_utils
-from ironic.common.i18n import _
 from ironic.common import image_service
 from ironic.common import images
 from ironic.common import utils
@@ -149,9 +148,6 @@ class ImageCache(object):
         :param ctx: context
         :param force_raw: boolean value, whether to convert the image to raw
                           format
-        :raise ImageDownloadFailed: when the image cache and the image HTTP or
-                                    TFTP location are on different file system,
-                                    causing hard link to fail.
         """
         # TODO(ghe): timeout and retry for downloads
         # TODO(ghe): logging when image cannot be created
@@ -164,13 +160,6 @@ class ImageCache(object):
             # will have link count >1 at any moment, so won't be cleaned up
             os.link(tmp_path, master_path)
             os.link(master_path, dest_path)
-        except OSError as exc:
-            msg = (_("Could not link image %(img_href)s from %(src_path)s "
-                     "to %(dst_path)s, error: %(exc)s") %
-                   {'img_href': href, 'src_path': master_path,
-                    'dst_path': dest_path, 'exc': exc})
-            LOG.error(msg)
-            raise exception.ImageDownloadFailed(msg)
         finally:
             utils.rmtree_without_raise(tmp_dir)
 
@@ -259,8 +248,8 @@ class ImageCache(object):
                          for f in os.listdir(self.master_dir))
         total_size = sum(os.path.getsize(f)
                          for f in total_listing)
-        while listing and (total_size > self._cache_size or
-                           (amount is not None and amount > 0)):
+        while listing and (total_size > self._cache_size
+                           or (amount is not None and amount > 0)):
             file_name, last_used, stat = listing.pop()
             try:
                 os.unlink(file_name)
@@ -431,8 +420,8 @@ def _delete_dest_path_if_stale(master_path, dest_path):
         # Image not cached, re-download
         return False
     master_path_exists = os.path.exists(master_path)
-    if (not master_path_exists or
-            os.stat(master_path).st_ino != os.stat(dest_path).st_ino):
+    if (not master_path_exists
+            or os.stat(master_path).st_ino != os.stat(dest_path).st_ino):
         # Image exists in cache, but dest_path out of date
         os.unlink(dest_path)
         return False
