@@ -167,8 +167,8 @@ def _is_node_in_use(server_hardware, applied_sp_uri, by_oneview=False):
     """
     operation = operator.ne if by_oneview else operator.eq
     server_profile_uri = server_hardware.get('serverProfileUri')
-    return (server_profile_uri and
-            operation(applied_sp_uri, server_profile_uri))
+    return (server_profile_uri
+            and operation(applied_sp_uri, server_profile_uri))
 
 
 def is_node_in_use_by_oneview(node):
@@ -368,7 +368,7 @@ def deallocate_server_hardware_from_ironic(task):
             task.driver.power.set_power_state(task, states.POWER_OFF)
             oneview_client.server_profiles.delete(server_profile_uri)
             _del_applied_server_profile_uri_field(node)
-            LOG.info("Server Profile %(server_profile_uuid)s was deleted "
+            LOG.info("Server Profile %(server_profile_uri)s was deleted "
                      "from node %(node_uuid)s in OneView.",
                      {'server_profile_uri': server_profile_uri,
                       'node_uuid': node.uuid})
