@@ -173,12 +173,19 @@ def set_boot_device(task):
 
 class OneViewManagement(base.ManagementInterface):
 
+    # NOTE(TheJulia): Marking as unsupported as 3rd party CI was taken down
+    # shortly before the beginning of the Rocky cycle, and no replies have
+    # indicated that 3rd party CI will be re-established nor visible
+    # actions observed regarding re-establishing 3rd party CI.
+    # TODO(TheJulia): This should be expected to be removed in Stein.
+    supported = False
+
     def get_properties(self):
         return deploy_utils.get_properties()
 
     @METRICS.timer('OneViewManagement.validate')
     def validate(self, task):
-        """Checks required info on 'driver_info' and validates node with OneView
+        """Checks required info on 'driver_info' and validates node for OneView
 
         Validates whether the 'driver_info' property of the supplied
         task's node contains the required info such as server_hardware_uri,
