@@ -27,22 +27,10 @@ from ironic.drivers.modules.ilo import common as ilo_common
 from ironic.drivers.modules.ilo import inspect as ilo_inspect
 from ironic.drivers.modules.ilo import power as ilo_power
 from ironic import objects
-from ironic.tests.unit.conductor import mgr_utils
-from ironic.tests.unit.db import base as db_base
-from ironic.tests.unit.db import utils as db_utils
-from ironic.tests.unit.objects import utils as obj_utils
+from ironic.tests.unit.drivers.modules.ilo import test_common
 
 
-INFO_DICT = db_utils.get_test_ilo_info()
-
-
-class IloInspectTestCase(db_base.DbTestCase):
-
-    def setUp(self):
-        super(IloInspectTestCase, self).setUp()
-        mgr_utils.mock_the_extension_manager(driver="fake_ilo")
-        self.node = obj_utils.create_test_node(
-            self.context, driver='fake_ilo', driver_info=INFO_DICT)
+class IloInspectTestCase(test_common.BaseIloTest):
 
     def test_get_properties(self):
         with task_manager.acquire(self.context, self.node.uuid,
@@ -266,13 +254,7 @@ class IloInspectTestCase(db_base.DbTestCase):
             create_port_mock.assert_called_once_with(task, macs)
 
 
-class TestInspectPrivateMethods(db_base.DbTestCase):
-
-    def setUp(self):
-        super(TestInspectPrivateMethods, self).setUp()
-        mgr_utils.mock_the_extension_manager(driver="fake_ilo")
-        self.node = obj_utils.create_test_node(
-            self.context, driver='fake_ilo', driver_info=INFO_DICT)
+class TestInspectPrivateMethods(test_common.BaseIloTest):
 
     @mock.patch.object(ilo_inspect.LOG, 'info', spec_set=True, autospec=True)
     @mock.patch.object(objects, 'Port', spec_set=True, autospec=True)
