@@ -27,23 +27,13 @@ from ironic.drivers.modules.ilo import common as ilo_common
 from ironic.drivers.modules.ilo import management as ilo_management
 from ironic.drivers.modules import ipmitool
 from ironic.drivers import utils as driver_utils
-from ironic.tests.unit.conductor import mgr_utils
-from ironic.tests.unit.db import base as db_base
-from ironic.tests.unit.db import utils as db_utils
+from ironic.tests.unit.drivers.modules.ilo import test_common
 from ironic.tests.unit.objects import utils as obj_utils
 
 ilo_error = importutils.try_import('proliantutils.exception')
 
-INFO_DICT = db_utils.get_test_ilo_info()
 
-
-class IloManagementTestCase(db_base.DbTestCase):
-
-    def setUp(self):
-        super(IloManagementTestCase, self).setUp()
-        mgr_utils.mock_the_extension_manager(driver="fake_ilo")
-        self.node = obj_utils.create_test_node(
-            self.context, driver='fake_ilo', driver_info=INFO_DICT)
+class IloManagementTestCase(test_common.BaseIloTest):
 
     def test_get_properties(self):
         with task_manager.acquire(self.context, self.node.uuid,
