@@ -386,6 +386,19 @@ class _TestObject(object):
         }
         self._test_get_changes(target_version='1.4')
 
+    @mock.patch('ironic.common.release_mappings.RELEASE_MAPPING',
+                autospec=True)
+    def test_get_changes_pinned_2versions(self, mock_release_mapping):
+        # obj_get_changes() is not affected by pinning
+        CONF.set_override('pin_release_version',
+                          release_mappings.RELEASE_VERSIONS[-1])
+        mock_release_mapping.__getitem__.return_value = {
+            'objects': {
+                'MyObj': ['1.3', '1.4'],
+            }
+        }
+        self._test_get_changes(target_version='1.4')
+
     def test_convert_to_version_same(self):
         # no changes
         obj = MyObj(self.context)
@@ -664,29 +677,29 @@ class TestObject(_LocalTest, _TestObject):
 # version bump. It is an MD5 hash of the object fields and remotable methods.
 # The fingerprint values should only be changed if there is a version bump.
 expected_object_fingerprints = {
-    'Node': '1.25-3a468b3e88d0a8fe7709f822fc654e4b',
+    'Node': '1.27-129323d486c03a99de27053503b2cae3',
     'MyObj': '1.5-9459d30d6954bffc7a9afd347a807ca6',
     'Chassis': '1.3-d656e039fd8ae9f34efc232ab3980905',
     'Port': '1.8-898a47921f4a1f53fcdddd4eeb179e0b',
     'Portgroup': '1.4-71923a81a86743b313b190f5c675e258',
-    'Conductor': '1.2-5091f249719d4a465062a1b3dc7f860d',
+    'Conductor': '1.3-d3f53e853b4d58cae5bfbd9a8341af4a',
     'EventType': '1.1-aa2ba1afd38553e3880c267404e8d370',
     'NotificationPublisher': '1.0-51a09397d6c0687771fb5be9a999605d',
-    'NodePayload': '1.8-2c327dfc77ce8c7a28b02eafaed509f0',
+    'NodePayload': '1.10-618d4ebd121671f463836b7c4ec45114',
     'NodeSetPowerStateNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'NodeSetPowerStatePayload': '1.8-916c39939609254de1f8050a1c8da7d1',
+    'NodeSetPowerStatePayload': '1.10-74b186077c80e13060de5e2dac9baed5',
     'NodeCorrectedPowerStateNotification':
         '1.0-59acc533c11d306f149846f922739c15',
-    'NodeCorrectedPowerStatePayload': '1.8-1afef2b5c0538941defa00232302cd89',
+    'NodeCorrectedPowerStatePayload': '1.10-f85fc83dceda2d7ed356368cda0f008f',
     'NodeSetProvisionStateNotification':
         '1.0-59acc533c11d306f149846f922739c15',
-    'NodeSetProvisionStatePayload': '1.8-d4aa7eb5a449e9f8271b3127a2d2b6ea',
+    'NodeSetProvisionStatePayload': '1.10-80e9581b0663dd47362f0b7ab19e4674',
     'VolumeConnector': '1.0-3e0252c0ab6e6b9d158d09238a577d97',
     'VolumeTarget': '1.0-0b10d663d8dae675900b2c7548f76f5e',
     'ChassisCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
     'ChassisCRUDPayload': '1.0-dce63895d8186279a7dd577cffccb202',
     'NodeCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'NodeCRUDPayload': '1.6-3ab7db0fc4574999fca91a1f04b4998f',
+    'NodeCRUDPayload': '1.8-8086c2706c8f89db8294ab7511b9337b',
     'PortCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
     'PortCRUDPayload': '1.2-233d259df442eb15cc584fae1fe81504',
     'NodeMaintenanceNotification': '1.0-59acc533c11d306f149846f922739c15',
@@ -986,3 +999,20 @@ class TestRegistry(test_base.TestCase):
         self.assertEqual(MyObj, mock_objects.MyObj)
         reg.registration_hook(MyOlderObj, 0)
         self.assertEqual(MyObj, mock_objects.MyObj)
+
+
+class TestMisc(test_base.TestCase):
+    def test_max_version(self):
+        versions = ['1.25', '1.33', '1.3']
+        maxv = base.max_version(versions)
+        self.assertEqual('1.33', maxv)
+
+    def test_max_version_one(self):
+        versions = ['1.25']
+        maxv = base.max_version(versions)
+        self.assertEqual('1.25', maxv)
+
+    def test_max_version_two(self):
+        versions = ['1.25', '1.26']
+        maxv = base.max_version(versions)
+        self.assertEqual('1.26', maxv)
